@@ -128,8 +128,11 @@ def generate_tasks(f):
     tasks_to_run = []
 
     should_use_sns = cli_command_helpers.get_should_use_sns(os.environ.get("AWS_DEFAULT_REGION"))
+    should_use_product_plans = cli_command_helpers.get_should_use_product_plans(os.environ.get("AWS_DEFAULT_REGION"))
 
-    task_defs = manifest_utils.convert_manifest_into_task_defs_for_launches(manifest, puppet_account_id, should_use_sns)
+    task_defs = manifest_utils.convert_manifest_into_task_defs_for_launches(
+        manifest, puppet_account_id, should_use_sns, should_use_product_plans
+    )
 
     for task in task_defs:
         task_status = task.get('status')
